package com.application.GUI;

import javafx.geometry.Pos;
import javafx.scene.*;
import javafx.scene.control.*;
import javafx.scene.layout.*;
import javafx.stage.*;
import org.checkerframework.checker.units.qual.K;

import java.util.Map;

import static com.application.DB.Constants.*;
import static com.application.DB.DB.setInputParameters;
import static com.application.GUI.LineChartFunctionality.loadSingleSeries;


/**
 * This class handles the popup input window
 *
 * @author Eilert Tunheim, Karin Pettersen, Mads Arnesen
 * @version 1.0
 */
public class InputPopUpWindow {

    public static void display()
    {
        Stage window = new Stage();

        window.initModality(Modality.APPLICATION_MODAL);
        window.setTitle("Input Parameters");

        // Top
        Label inputLabel= new Label("Input");
        inputLabel.setId("inputTop");

        // Center - Input fields
        // Tree species
        Label treeSpeciesInputLabel = new Label("Tree Species");
        treeSpeciesInputLabel.setId("inputLabel");
        TextField treeSpeciesInputText = new TextField();
        treeSpeciesInputText.setId("inputLabelText");
        treeSpeciesInputText.setPromptText("Bjørk");
        treeSpeciesInputText.getText();

        // Width
        Label widthInputLabel = new Label("Width");
        widthInputLabel.setId("inputLabel");
        TextField widthInputText = new TextField();
        widthInputText.setId("inputLabelText");
        widthInputText.setPromptText("47");

        // Height
        Label heightInputLabel = new Label("Height");
        heightInputLabel.setId("inputLabel");
        TextField heightInputText = new TextField();
        heightInputText.setId("inputLabelText");
        heightInputText.setPromptText("200");

        // Sawset
        Label sawsetInputLabel = new Label("Sawset");
        sawsetInputLabel.setId("inputLabel");
        TextField sawsetInputText = new TextField();
        sawsetInputText.setId("inputLabelText");
        sawsetInputText.setPromptText("4x");

        // Moisture
        Label moistureGoalInputLabel = new Label("Moisture Goal");
        moistureGoalInputLabel.setId("inputLabel");
        TextField moistureGoalInputText = new TextField();
        moistureGoalInputText.setId("inputLabelText");
        moistureGoalInputText.setPromptText("12%");


        // Bottom - start button
        Button startButton = new Button("Start");
        startButton.setId("inputButtonStart");

        startButton.setOnAction(e -> {
            TREE_SPECIES = treeSpeciesInputText.getText();
            WIDTH_DIMENTION = widthInputText.getText();
            HEIGHT_DIMENTION = heightInputText.getText();
            SAWSET = sawsetInputText.getText();
            MOISTURE_GOAL = moistureGoalInputText.getText();

            window.close();


            class KwhThread implements Runnable {

                Map<Integer, Map<String, Number>> dataVariable;
                private volatile boolean finished;

                @Override
                public void run() {
                    try{
                        dataVariable = setInputParameters();
                    } catch (Exception ex) {
                        ex.printStackTrace();
                    }
                    finished = true;

                    synchronized (this){
                        this.notify();
                    }
                }



                public Map<Integer, Map<String, Number>> getDataVariable() throws InterruptedException {

                    synchronized (this){
                        if(!finished)
                        this.wait();
                    }
                    return dataVariable;
                }
            }

            KwhThread kwhThread = new KwhThread();

            Thread thread = new Thread(kwhThread);
            thread.setName("GetKwhThread");
            thread.start();

            try {
                loadSingleSeries(kwhThread.getDataVariable());
            } catch (Exception ex) {
                ex.printStackTrace();
            }





            /*
            // Fungerende ny thread!!@@@@@
            try{
                Thread thread = new Thread(new Runnable() {

                    @Override
                    public void run() {
                        try {
                            loadSingleSeries(setInputParameters());
                            //loadSingleSeries();
                            //loadMultipleSeries();
                        } catch (Exception ex) {
                            ex.printStackTrace();
                        }
                    }
                });
                thread.start();
                //thread.join();
            } catch (Exception ex) {
                ex.printStackTrace();
            }

             */
        });

        VBox layout = new VBox(10);
        layout.getChildren().addAll(inputLabel, treeSpeciesInputLabel, treeSpeciesInputText, widthInputLabel, widthInputText, heightInputLabel, heightInputText,
                sawsetInputLabel, sawsetInputText, moistureGoalInputLabel, moistureGoalInputText, startButton);
        layout.setAlignment(Pos.CENTER);

        Scene scene = new Scene(layout, 600, 500);
        scene.getStylesheets().add(InputPopUpWindow.class.getResource("/com.application/CSS/styleSheet.css").toExternalForm());
        window.setScene(scene);
        window.showAndWait();
    }

}
